/*

    QBabbel, a simple VoIP chat utility using JVOIPLIB 
    Copyright (C) 2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "qbabbelimpl.h"
#include <jvoipsessionparams.h>
#include <jvoiprtptransmission.h>
#include <jvoipsoundcardparams.h>
#include <stdlib.h>
#include <iostream>
#include <qtimer.h>
#include <qprogressbar.h>

QBabbelImpl::QBabbelImpl(unsigned long destip,unsigned short destport,int imul) throw (JVOIPException) : QBabbel(0,"QBabbel",true),chatinput(this),chatoutput(this)
{
	JVOIPSessionParams sessparams;
	JVOIPRTPTransmissionParams transparams;
	JVOIPSoundcardParams sndparams;
	int status;

	inputBar->setTotalSteps(200);
	outputBar->setTotalSteps(200);
	inputBar->setPercentageVisible(false);
	outputBar->setPercentageVisible(false);
	
	sndparams.SetMultiplyFactor(imul);
	transparams.SetAcceptOwnPackets(true);
	sessparams.SetSampleInterval(20);
	sessparams.SetTransmissionParams(&transparams);
	sessparams.SetVoiceInputParams(&sndparams);
	// TODO: use Speex when new version of library is released
	sessparams.SetCompressionType(JVOIPSessionParams::GSM);
	sessparams.SetVoiceInputType(JVOIPSessionParams::UserDefinedInput);
	sessparams.SetVoiceOutputType(JVOIPSessionParams::UserDefinedOutput);
	status = JVOIPSession::Create(sessparams);
	if (status < 0)
	{
		std::cerr << "Couldn't create session" << std::endl;
		exit(-1);
	}
	JVOIPSession::AddDestination(destip,destport);

	QTimer *t = new QTimer(this);
	QObject::connect(t,SIGNAL(timeout()),this,SLOT(OnTimeout()));
	t->start(20);
}

QBabbelImpl::~QBabbelImpl() throw (JVOIPException)
{
	JVOIPSession::Destroy();
}

void QBabbelImpl::OnTimeout()
{
	double inavg = chatinput.GetSampleAverage();
	double outavg = chatoutput.GetSampleAverage();

	inputBar->setProgress((int)(inavg*200.0));
	outputBar->setProgress((int)(outavg*200.0));
}

